Learn R Programming

CIAAWconsensus (version 1.3)

ciaaw.mass.2016: Atomic masses of isotopes (IUPAC/CIAAW 2016)

Description

This data set gives the atomic masses and uncertainties of all polyisotopic nuclides as they are used by the IUPAC/CIAAW.

Usage

ciaaw.mass.2016

Arguments

Format

A data frame with 268 rows and 4 variables:

  • isotope: Symbol of the isotope

  • element: Name of the element (lowercase english)

  • mass: Atomic mass of the isotope in daltons

  • uncertainty: Uncertainty of the atomic mass of the isotope as used by the IUPAC-CIAAW